@@ -1,6 +1,6 @@
 import numpy as np
 
-from . import Material, Variable
+from . import Material, MaterialTensor, Variable
 from .math import det, horzcat, vertcat, zeros, gradient as grad, trace, eye, Function
 
 
@@ -185,3 +185,23 @@ class MaterialComposite:
     def hessian(self, x, **kwargs):
         hess = [m.hessian(x, **kwargs) for m in self.materials]
         return [np.sum([h[a] for h in hess], 0) for a in range(len(hess[0]))]
+
+
+class MaterialTensorGeneral(MaterialTensor):
+    def __init__(self, fun, statevars_shape=(1, 1), x=None, triu=True, **kwargs):
+        """A (first Piola-Kirchhoff stress) tensor-based material definition with
+        state variables of a given shape."""
+
+        if x is None:
+            x = [Variable("F", 3, 3)]
+
+        try:
+            # displacement-pressure split
+            x.append(fun.p)
+        except:
+            pass
+
+        # add state variables
+        x.append(Variable("z", *statevars_shape))
+
+        super().__init__(x=x, fun=fun, triu=triu, statevars=1, kwargs=kwargs)
