@@ -5,6 +5,7 @@ from matadi import (
     MaterialHyperelasticPlaneStressIncompressible,
     MaterialHyperelasticPlaneStressLinearElastic,
     ThreeFieldVariationPlaneStrain,
+    TwoFieldVariationPlaneStrain,
 )
 from matadi.models import neo_hooke, linear_elastic
 
@@ -36,7 +37,10 @@ def test_plane_strain():
     FF = pre()
 
     # init Material
-    W = MaterialHyperelasticPlaneStrain(fun=neo_hooke, C10=0.5,)
+    W = MaterialHyperelasticPlaneStrain(
+        fun=neo_hooke,
+        C10=0.5,
+    )
 
     W0 = W.function([FF])
     dW = W.gradient([FF])
@@ -57,7 +61,10 @@ def test_plane_strain_mixed():
     FF, pp, JJ = pre_mixed()
 
     # init Material
-    W = MaterialHyperelasticPlaneStrain(fun=neo_hooke, C10=0.5,)
+    W = MaterialHyperelasticPlaneStrain(
+        fun=neo_hooke,
+        C10=0.5,
+    )
 
     W_upJ = ThreeFieldVariationPlaneStrain(W)
 
@@ -73,6 +80,20 @@ def test_plane_strain_mixed():
     assert dW[0].shape == (2, 2, 8, 1000)
     assert DW[0].shape == (2, 2, 2, 2, 8, 1000)
 
+    W_up = TwoFieldVariationPlaneStrain(W)
+
+    W0 = W_up.function([FF, pp])
+    dW = W_up.gradient([FF, pp])
+    DW = W_up.hessian([FF, pp])
+
+    assert W0[0].shape == (1, 1, 8, 1000)
+    assert dW[0].shape == (2, 2, 8, 1000)
+    assert DW[0].shape == (2, 2, 2, 2, 8, 1000)
+
+    assert W0[0].shape == (1, 1, 8, 1000)
+    assert dW[0].shape == (2, 2, 8, 1000)
+    assert DW[0].shape == (2, 2, 2, 2, 8, 1000)
+
 
 def test_plane_stress_incompr():
 
@@ -80,7 +101,10 @@ def test_plane_stress_incompr():
     FF = pre()
 
     # init Material
-    W = MaterialHyperelasticPlaneStressIncompressible(fun=neo_hooke, C10=0.5,)
+    W = MaterialHyperelasticPlaneStressIncompressible(
+        fun=neo_hooke,
+        C10=0.5,
+    )
 
     W0 = W.function([FF])
     dW = W.gradient([FF])
@@ -102,7 +126,9 @@ def test_plane_stress_linear():
 
     # init Material
     W = MaterialHyperelasticPlaneStressLinearElastic(
-        fun=linear_elastic, mu=1.0, lmbda=200.0,
+        fun=linear_elastic,
+        mu=1.0,
+        lmbda=200.0,
     )
 
     W0 = W.function([FF])
